﻿------------------------------------------------------------------------------------------
--Config UI-------------------------------------------------------------------------------
------------------------------------------------------------------------------------------
local SN, L, F, T, M, _ = unpack(select(2,...))
local LSM = LibStub("LibSharedMedia-3.0")

local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceDB = LibStub("AceDB-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")
local AceConfigRegistry = LibStub("AceConfigRegistry-3.0")
local LibDualSpec = LibStub('LibDualSpec-1.0')
local CLASS_SORT_ORDER = CLASS_SORT_ORDER
local AceGUIWidgetLSMlists = AceGUIWidgetLSMlists
local GetSpellInfo = GetSpellInfo
local IsAddOnLoaded = IsAddOnLoaded
local pairs = pairs
local ReloadUI = ReloadUI
local strconcat = strconcat
local strlower = strlower
local strsub = strsub
local unpack = unpack
local selectedSpell

local function profileUpdate()
	db = SN.data
	local frames = { F.powermover, F.classpower, F.cooldowns, F.dispel }

	for i, frame in pairs(frames) do
		if frame then
			frame:ClearAllPoints()
		end
	end

	if (IsAddOnLoaded("ElvUI")) then
		F.cooldowns:SetPoint(unpack(db.profile.frames.elvcooldowns))
		F.cooldowns:SetStartPoint(SN.data.profile.cooldown.elvgrow)
		F.debuffs:SetPoint(unpack(db.profile.frames.elvdebuffs))
		F.debuffs:SetStartPoint(SN.data.profile.debuffs.grow)
	else
		F.cooldowns:SetPoint(unpack(db.profile.frames.cooldowns))
		F.cooldowns:SetStartPoint(SN.data.profile.cooldown.grow)
		F.debuffs:SetPoint(unpack(db.profile.frames.debuffs))
		F.debuffs:SetStartPoint(SN.data.profile.debuffs.grow)
	end
	--Refresh the cooldown settings
	F.cooldowns:SetWidth(SN.data.profile.cooldown.width)
	if F.cooldowns.bars ~= nil then
		local bars = F.cooldowns.bars
		for i in pairs(bars) do
			i:SetHeight(SN.data.profile.cooldown.height)
			i:SetLabelFont(LSM:Fetch("font", SN.data.profile.cooldown.font), SN.data.profile.cooldown.fontsize)
			i:SetDurationFont(LSM:Fetch("font", SN.data.profile.cooldown.font), SN.data.profile.cooldown.fontsize)
			i:SetTexture(LSM:Fetch("statusbar", SN.data.profile.cooldown.texture))
		end
	end
	--Refresh the debuff settings
	F.debuffs:SetWidth(SN.data.profile.debuffs.width)
	if F.debuffs.bars ~= nil then
		local bars = F.debuffs.bars
		for i in pairs(bars) do
			i:SetHeight(SN.data.profile.debuffs.height)
			i:SetLabelFont(LSM:Fetch("font", SN.data.profile.debuffs.font), SN.data.profile.debuffs.fontsize)
			i:SetDurationFont(LSM:Fetch("font", SN.data.profile.debuffs.font), SN.data.profile.debuffs.fontsize)
			i:SetTexture(LSM:Fetch("statusbar", SN.data.profile.debuffs.texture))
		end
	end
	F.classpower:SetPoint(unpack(db.profile.frames.classpower))
	F.dispel:SetPoint(unpack(db.profile.frames.dispel))
	--Refresh the classpower settings
	SN:ClassResize()
	if F.classpower.runes ~= nil then
		for i = 1, F.classpower.runes.maxRunes do
			F.classpower.runes[i]:SetOrientation(SN.data.profile.classResources.orientation)
		end
	end
	if F.classpower.frame ~= nil then
		for i = 1, #F.classpower.frame do
			F.classpower.frame[i]:SetStatusBarTexture(LSM:Fetch("statusbar", SN.data.profile.classResources.texture))
		end
	end
	--Refresh the powerbar settings
	F.powermover:SetPoint(unpack(db.profile.frames.powerbar))
	F.powermover:SetSize(SN.data.profile.powerbar.width, SN.data.profile.powerbar.height)
	F.container:SetSize(SN.data.profile.powerbar.width, SN.data.profile.powerbar.height)
	F.power:SetSize(SN.data.profile.powerbar.width - 2, SN.data.profile.powerbar.height - 2)
	F.power:SetStatusBarTexture(LSM:Fetch("statusbar", SN.data.profile.powerbar.texture))
	F.power.value:SetFont(LSM:Fetch("font", SN.data.profile.powerbar.font), SN.data.profile.powerbar.fontsize, "OUTLINE")
	
	if SN.data.profile.powerbar.tickenable then
		if not F.power.tick:IsShown() then
			F.power.tick:Show()
		end
	else
		F.power.tick:Hide()
	end
end

function SN:Initialize()
	db = AceDB:New("SNDB", SN.DB, "Default")
	SN.data = db
	LibDualSpec:EnhanceDatabase(db, "SN")
	SN.data.profile.classSelect.default = SN.playerClass

	db.RegisterCallback(self, "OnProfileChanged", profileUpdate)
	db.RegisterCallback(self, "OnProfileCopied", profileUpdate)
	db.RegisterCallback(self, "OnProfileReset", profileUpdate)
	SN:SetupConfig()
	SN:LoadConfig()
end

SN.TexCoords = {.08, .92, .08, .92}

function SN:LoadConfig()
	AceConfig:RegisterOptionsTable("SN", SN.options, nil)
	SN.options.args.profile = AceDBOptions:GetOptionsTable(SN.data)
		
	SN.optionsFrames = {}
	SN.optionsFrames.general = AceConfigDialog:AddToBlizOptions("SN", "Serenity Now", nil, "general")
	SN.optionsFrames.profile = AceConfigDialog:AddToBlizOptions("SN", "Profiles", "Serenity Now", "profile")
	
	LibDualSpec:EnhanceOptions(SN.options.args.profile, SN.data)
end

function SN:FrameMoverPopUp(value)
	SN:MoveFrames(value)
	F.FrameMoverPopUp = CreateFrame("Frame", "FrameMoverPopUp", UIParent)
	F.FrameMoverPopUp:SetSize(250, 50)
	F.FrameMoverPopUp:SetPoint("CENTER", nil, "CENTER", 0, 300)
	F.FrameMoverPopUp:SetFrameStrata("DIALOG")
	F.FrameMoverPopUp:SetToplevel(true)
	F.FrameMoverPopUp:EnableMouse(true)
	F.FrameMoverPopUp:SetMovable(true)
	F.FrameMoverPopUp:SetFrameLevel(99)
	F.FrameMoverPopUp:SetClampedToScreen(true)

	if (IsAddOnLoaded("ElvUI")) then
		SN:SNCreateBG(F.FrameMoverPopUp, "Frame")
	else
		F.FrameMoverPopUp:SetBackdrop({
			bgFile = M.media.blankTex, 
			edgeFile = M.media.blankTex, 
			tile = false, tileSize = 0, edgeSize = 2, 
			insets = { left = 2, right = 2, top = 2, bottom = 2 }
			})
		F.FrameMoverPopUp:SetBackdropColor(0.1, 0.1, 0.1, 1)
		F.FrameMoverPopUp:SetBackdropBorderColor(0.1, 0.1, 0.1, 1)
	end

	F.FrameMoverPopUp.text = F.FrameMoverPopUp:CreateFontString(nil, "ARTWORK")
	F.FrameMoverPopUp.text:SetFont(M.media.font, 12, "OUTLINE")
	F.FrameMoverPopUp.text:SetText(L["Frame Mover"])
	F.FrameMoverPopUp.text:SetAllPoints(F.FrameMoverPopUp)
	F.FrameMoverPopUp.text:SetJustifyH("CENTER")
	F.FrameMoverPopUp.text:SetJustifyV("TOP")

	F.FrameMoverPopUp.lock = CreateFrame("Button", "FrameMoverPopUpCloseButton", F.FrameMoverPopUp, "OptionsButtonTemplate")
	F.FrameMoverPopUp.lock:SetText(L["Lock"])
	if (IsAddOnLoaded("ElvUI")) then
		SN:SNCreateBG(F.FrameMoverPopUp.lock, "Button")
	end
	F.FrameMoverPopUp.lock:SetPoint("BOTTOM", F.FrameMoverPopUp, "BOTTOM", 0, 5)
	F.FrameMoverPopUp.lock:SetWidth(50)

	F.FrameMoverPopUp.lock:SetScript("OnClick", function(self)
		local ACD = LibStub("AceConfigDialog-3.0")
		F.FrameMoverPopUp:Hide()
		SN:MoveFrames(true)
		InterfaceOptionsFrame_OpenToCategory("Serenity Now")
	end)
end
function SN:SetupConfig()
SN.options.args = {
	general = {
		type = "group",
		name = "general",
		args = {
			descrip = {
				order = 0,
				type = "description",
				name = L["A tool to have as much of the needed information from each class\nwithin eye sight so that you can say Serenity Now!"],
			},
			h1 = {
				order = 1,
				type = "header",
				name = "",
			},
				
			lock = {
				order = 2,
				name = L["Lock Frames"],
				type = 'toggle',
				get = function(info)
					return SN.data.profile.frames[info[#info]] 
				end,
				set = function(info, value)
					SN:Debug(info[#info])
					SN:FrameMoverPopUp(value)
				end,
			},
			debug = {
				order = 2,
				name = L["Debug Mode"],
				type = "toggle",
				get = function()
					return SN.data.profile.debug.enable 
				end,
				set = function(key, value)
					SN.data.profile.debug.enable = value
				end,
			},
			configure = {
				order = 6,
				type = "execute",
				name = L["Apply Changes"],
				desc = L["Apply changes and reload the UI"],
				func = function()
					ReloadUI()
				end,
				order = 1,
				width = "normal",
			},
			h2 = {
				order = 7,
				type = "header",
				name = "",
			},
			cooldown = {
				order = 24,
				type = "group",
				name = L["Cooldowns"],
				args = {
					enableall = {
						name = L["Enable All CD's"],
						type = "execute",
						order = 0,
						func = function()
							for i, cd in pairs(SN.data.profile.cooldowns) do
								cd.enable = true
							end
						end,
						width = "normal",
					},
					disableall = {
						name = L["Disable All CD's"],
						type = "execute",
						order = 1,
						func = function()
							for i, cd in pairs(SN.data.profile.cooldowns) do
								cd.enable = false
							end
						end,
						width = "normal",
					},
					castannounce = {
						type = "toggle",
						name = L["Announce Casts"],
						desc = L["You will only announce if you are the Raid Leader"],
						order = 2,
						get = function(info)
							return SN.data.profile.cooldown[info[#info]]
						end,
						set = function(info, value)
							SN.data.profile.cooldown[info[#info]] = value
						end,
					},
					raid = {
						order = 3,
						name = L["Raid Cooldowns"],
						desc = L["Uncheck to show only your personal CD's"],
						type = "toggle",
						get = function(info)
							return SN.data.profile.cooldown[info[#info]]
						end,
						set = function(info, value)
							SN.data.profile.cooldown[info[#info]] = value
						end,
					},
					h3 = {
						order = 4,
						type = "header",
						name = "Dimensions",
					},
					width = {
						type = "range",
						name = L["Width of CD Bars"],
						order = 6,
						min = 50, max = 500, step = 1,
						get = function(info)
							return SN.data.profile.cooldown[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.cooldown[info[#info]] = value
							F.cooldowns:SetWidth(value)
						end,
					},
					height = {
						type = "range",
						name = L["Height of CD Bars"],
						order = 7,
						min = 12, max = 30, step = 1,
						get = function(info)
							return SN.data.profile.cooldown[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.cooldown[info[#info]] = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetHeight(value)
								end
							end
						end,
					},
					h4 = {
						order = 8,
						type = "header",
						name = "Font",
					},
					font = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 10,
						values = AceGUIWidgetLSMlists.font,
						get = function(info) return SN.data.profile.cooldown[info[#info]] end,--selectedClass end,
						set = function(info, value)
							SN.data.profile.cooldown[info[#info]] = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", value), SN.data.profile.cooldown.fontsize)
									i:SetDurationFont(LSM:Fetch("font", value), SN.data.profile.cooldown.fontsize)
								end
							end
						end,
					},
					fontsize = {
						type = "range",
						name = L["Font Size of CD Bars"],
						order = 11,
						min = 10, max = 24, step = 1,
						get = function(info)
							return SN.data.profile.cooldown[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.cooldown[info[#info]] = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", SN.data.profile.cooldown.font), value)
									i:SetDurationFont(LSM:Fetch("font", SN.data.profile.cooldown.font), value)
								end
							end
						end,
					},
					h5 = {
						order = 12,
						type = "header",
						name = "Texture",
					},
					texture = {
						type = "select",
						dialogControl = 'LSM30_Statusbar',
						name = L["Texture"],
						order = 14,
						values = AceGUIWidgetLSMlists.statusbar,
						get = function(info) return SN.data.profile.cooldown[info[#info]] end,
						set = function(info, value)
							SN.data.profile.cooldown[info[#info]] = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetTexture(LSM:Fetch("statusbar", value))
								end
							end
						end,
					},
					cooldowns = {
						order = 0,
						type = "group",
						name = L["CD List"],
						args = {
							selectClass = {
								name = L["Select Class"],
								type = "select",
								order = 0,
								values = function()
									local values = { } 
									for _, class in pairs(CLASS_SORT_ORDER) do
										local class1 = strsub(class, 1, 1)
										class1 = strconcat(class1, strlower(strsub(class, 2)))
										values[class] = class1
									end
									return values
								end,
								get = function(info) return SN.data.profile.classSelect.default end,--selectedClass end,
								set = function(info, value)
									--selectedClass = value
									SN.data.profile.classSelect.default = value
								end,
							},
							h6 = {
								order = 2,
								type = "header",
								name = "",
							},
							selectSpell = {
								name = L["Select Spell"],
								type = "multiselect",
								order = 4,						
								values = function()
									local values = {}
									for _, spell in pairs(SN.data.profile.cooldowns) do
										if SN.data.profile.classSelect.default == spell.class then--selectedClass == spell.class then
											local name, _, icon = GetSpellInfo(spell.id)
											values[spell.id] = name
										end
									end
									return values
								end,
								get = function(info, spid) 
									for _, spell in pairs(SN.data.profile.cooldowns) do
										if spid == spell.id then
											return spell.enable
										end
									end
								end,
								set = function(info, spid, value)
									for _, spell in pairs(SN.data.profile.cooldowns) do
										if spid == spell.id then
											spell.enable = value
										end
									end
								end,
							},
						},
					},
				},
			},
			debuffs = {
				order = 25,
				type = "group",
				name = L["Debuffs"],
				args = {
					enable = {
						type = "toggle",
						name = L["Enable Debuff Bars"],
						order = 0,
						get = function(info)
							return SN.data.profile.debuffs[info[#info]]
						end,
						set = function(info, value)
							SN.data.profile.debuffs[info[#info]] = value

							if value == true then
								SN:DebuffEnable()
							elseif value == false then
								SN:DebuffDisable()
							end
						end,
					},
					h7 = {
						order = 2,
						type = "header",
						name = "Dimensions",
					},
					width = {
						type = "range",
						name = L["Width of Debuff Bars"],
						order = 4,
						min = 50, max = 500, step = 1,
						get = function(info)
							return SN.data.profile.debuffs[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.debuffs[info[#info]] = value
							F.debuffs:SetWidth(value)
						end,
					},
					height = {
						type = "range",
						name = L["Height of Debuff Bars"],
						order = 5,
						min = 12, max = 30, step = 1,
						get = function(info)
							return SN.data.profile.debuffs[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.debuffs[info[#info]] = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetHeight(value)
								end
							end
						end,
					},
					h8 = {
						order = 6,
						type = "header",
						name = "Font",
					},
					font = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 8,
						values = AceGUIWidgetLSMlists.font,
						get = function(info) return SN.data.profile.debuffs[info[#info]] end,--selectedClass end,
						set = function(info, value)
							SN.data.profile.debuffs[info[#info]] = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", value), SN.data.profile.debuffs.fontsize)
									i:SetDurationFont(LSM:Fetch("font", value), SN.data.profile.debuffs.fontsize)
								end
							end
						end,
					},
					fontsize = {
						type = "range",
						name = L["Font Size of Debuff Bars"],
						order = 9,
						min = 10, max = 24, step = 1,
						get = function(info)
							return SN.data.profile.debuffs[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.debuffs[info[#info]] = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", SN.data.profile.debuffs.font), value)
									i:SetDurationFont(LSM:Fetch("font", SN.data.profile.debuffs.font), value)
								end
							end
						end,
					},
					h9 = {
						order = 12,
						type = "header",
						name = "Texture",
					},
					texture = {
						type = "select",
						dialogControl = 'LSM30_Statusbar',
						name = L["Texture"],
						order = 14,
						values = AceGUIWidgetLSMlists.statusbar,
						get = function(info) return SN.data.profile.debuffs[info[#info]] end,
						set = function(info, value)
							SN.data.profile.debuffs[info[#info]] = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetTexture(LSM:Fetch("statusbar", value))
								end
							end
						end,
					},
				},
			},
			powerbar = {
				order = 24,
				type = "group",
				name = L["Powerbar"],
				args = {
					enable = {
						order = 0,
						type = "toggle",
						name = L["Enable Powerbar"],
						get = function(info)
							return SN.data.profile.powerbar[info[#info]]
						end,
						set = function(info, value)
							if value == true then
								SN:PowerEnable()
							else
								SN:PowerDisable()
							end
							SN.data.profile.powerbar[info[#info]] = value
							if IsAddOnLoaded("ElvUI") then
								SN:ElvOverride()
							end
						end,
					},
					tickenable = {
						order = 1,
						name = L["Powerbar Ticks Marks"],
						desc = L["Tick marks on the powerbar to represent how much power you need to cast your main spell."],
						type = "toggle",
						get = function()
							return SN.data.profile.powerbar.tickenable
						end,
						set = function(key, value)
							SN.data.profile.powerbar.tickenable = value
							if value == true then
								F.power.tick:Show()
							else
								F.power.tick:Hide()
							end
						end,
					},
					h10 = {
						order = 2,
						type = "header",
						name = "Dimensions",
					},
					width = {
						type = "range",
						name = L["Width of Powerbar"],
						order = 4,
						min = 50, max = 500, step = 1,
						get = function(info)
							return SN.data.profile.powerbar[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.powerbar[info[#info]] = value
							F.container:SetWidth(value)
							if (IsAddOnLoaded("ElvUI")) then
								F.container:SetWidth(value)
								F.power:SetWidth(value - 2)
							else
								F.power:SetWidth(value - 4)
							end
						end,
					},
					height = {
						type = "range",
						name = L["Height of Powerbar"],
						order = 5,
						min = 12, max = 30, step = 1,
						get = function(info)
							return SN.data.profile.powerbar[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.powerbar[info[#info]] = value
							F.container:SetHeight(value)
							if (IsAddOnLoaded("ElvUI")) then
								F.container:SetHeight(value)
								F.power:SetHeight(value - 2)
							else
								F.power:SetHeight(value - 4)
							end
						end,
					},
					h11 = {
						order = 6,
						type = "header",
						name = "Font",
					},
					font = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 8,
						values = AceGUIWidgetLSMlists.font,
						get = function(info) return SN.data.profile.powerbar[info[#info]] end,--selectedClass end,
						set = function(info, value)
							SN.data.profile.powerbar[info[#info]] = value
							F.power.value:SetFont(LSM:Fetch("font", value), SN.data.profile.powerbar.fontsize, "OUTLINE")
						end,
					},
					fontsize = {
						type = "range",
						name = L["Font Size of Powerbar"],
						order = 9,
						min = 10, max = 24, step = 1,
						get = function(info)
							return SN.data.profile.powerbar[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.powerbar[info[#info]] = value
							F.power.value:SetFont(LSM:Fetch("font", SN.data.profile.powerbar.font), value, "OUTLINE")
						end,
					},
					h12 = {
						order = 10,
						type = "header",
						name = "Texture",
					},
					texture = {
						type = "select",
						dialogControl = 'LSM30_Statusbar',
						name = L["Texture"],
						order = 12,
						values = AceGUIWidgetLSMlists.statusbar,
						get = function(info) return SN.data.profile.powerbar[info[#info]] end,
						set = function(info, value)
							SN.data.profile.powerbar[info[#info]] = value
							F.power:SetStatusBarTexture(LSM:Fetch("statusbar", value))
						end,
					},
				},
			},
			classResources = {
				order = 25,
				type = "group",
				name = L["Class Power"],
				args = {
					enable = {
						order = 0,
						type = "toggle",
						name = L["Enable Class Power"],
						get = function(info)
							return SN.data.profile.classResources[info[#info]]
						end,
						set = function(info, value)
							if value == true then
								SN:ClassEnable()
							else
								SN:ClassDisable()
							end
							SN.data.profile.classResources[info[#info]] = value
							if IsAddOnLoaded("ElvUI") then
								SN:ElvOverride()
							else
								SN:BlizzClassPower(info, value)
							end
						end,
					},
					orientation = {
						order = 1,
						type = "select",
						name = L["Rune Fill Direction"],
						values = {
							["HORIZONTAL"] = "HORIZONTAL",
							["VERTICAL"] = "VERTICAL",
						},
						get = function(info)
							return SN.data.profile.classResources[info[#info]]
						end,
						set = function(info, value)
							for i = 1, 6 do
								F.classpower.runes[i]:SetOrientation(value)
							end
							SN.data.profile.classResources[info[#info]] = value							
						end,
					},
					h = {
						order = 2,
						type = "header",
						name = "Dimensions",
					},
					width = {
						type = "range",
						name = L["Width of Class Power"],
						order = 4,
						min = 50, max = 500, step = 1,
						get = function(info)
							return SN.data.profile.classResources[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.classResources[info[#info]] = value
							SN:ClassResize()
						end,
					},
					height = {
						type = "range",
						name = L["Height of Class Power"],
						order = 5,
						min = 10, max = 100, step = 1,
						get = function(info)
							return SN.data.profile.classResources[info[#info]] 
						end,
						set = function(info, value)
							SN.data.profile.classResources[info[#info]] = value
							SN:ClassResize()
						end,
					},
					texture = {
						type = "select",
						dialogControl = 'LSM30_Statusbar',
						name = L["Texture"],
						order = 14,
						values = AceGUIWidgetLSMlists.statusbar,
						get = function(info) return SN.data.profile.classResources[info[#info]] end,
						set = function(info, value)
							SN.data.profile.classResources[info[#info]] = value
							if F.classpower.frame ~= nil then
								for i = 1, #F.classpower.frame do
									for v = 1, #F.classpower.frame[i] do
										F.classpower.frame[i][v]:SetStatusBarTexture(LSM:Fetch("statusbar", value))
									end
								end
							end
						end,
					},
				},
			},
			dispel = {
				order = 26,
				type = "group",
				name = L["Dispel"],
				args = {
					enable = {
						type = "toggle",
						name = L["Enable Dispel System"],
						order = 0,
						get = function(info)
							return SN.data.profile.dispel[info[#info]]
						end,
						set = function(info, value)
							if value == true then
								F.dispel:Show()
							else
								F.dispel:Hide()
							end
							SN.data.profile.dispel[info[#info]] = value
						end,
					},
				},
			},
		},
	},
}
end
			
				--threat = {
				--	order = 26,
				--	type = "group",
				--	name = L["Threat"],
				--	args = { 
				--		threatenable = {
				--			type = "toggle",
				--			name = L["Enable Threat System"],
				--			order = 0,
				--			get = function()
				--				return SN.db.profile.threat.enable
				--			end,
				--			set = function(key, value)
				--				if value == true then
				--					SN.F.threat:Show()
				--				else
				--					SN.F.threat:Hide()
				--				end
				--				SN.db.profile.threat.enable = value
				--			end,
				--		},
				--	},
				--},
				
				
	